﻿
local MAJOR, MINOR = "LibMounts-1.0", tonumber("20101011232139") or 99999999999999 -- dev version should ovewrite normal version
local lib = LibStub:NewLibrary(MAJOR, MINOR)

if not lib then return end

lib.data = LibStub("LibMounts-1.0_Data")

local function assertMount(id)
	local found
	for k, t in pairs(lib.data) do
		if k ~= specialSpeed and t[id] then
			found = true
		end
	end
	if not found then
		local name = GetSpellInfo(id)
		if name then
			print("|cFF33FF99LibMounts-1.0|r: |cFFFF2222"..name.."|r was not found in the mount database. If this is a valid mount, please contact us at http://www.wowace.com/addons/libmounts-1-0/ to get this mount added ASAP")
		else
			print("|cFF33FF99LibMounts-1.0|r: |cFFFF2222"..id.."|r is not a valid Mount Spell ID")
		end
	end
end
--- Retrieves Mount Information including type, speed and location restrictions
-- @param id Spell id of a Mount
-- @usage local ground, air, water, speed, location = LibStub("LibMounts-1.0"):GetMountInfo(id)
-- @return **ground** <<color 00f>>boolean<</color>> true if mount is primarily a ground mount (or can switch between ground and air only modes)
-- @return **air** <<color 00f>>boolean<</color>> true if mount is primarily an air mount (or can switch between air and ground only modes)
-- @return **water** <<color 00f>>boolean<</color>> true if mount is primarily a water mount
-- @return **speed** <<color 00f>>number<</color>> speed of mount if non standard (will always be slower than standard)
-- @return **location** <<color 00f>>string<</color>> location this mount is restricted to (valid returns are "AQ" for the bug mounts and "Vashj'ir" for the Seahorse)
function lib:GetMountInfo(id)
	assertMount(id)
	if lib.data["specialLocation"][id] then
		return unpack(lib.data["specialLocation"][id])
	else
		return lib.data["ground"][id], lib.data["air"][id], lib.data["water"][id], lib.data["specialSpeed"][id]
	end
end

lib.normalTypes = {
	["ground"] = true,
	["air"] = true,
	["water"] = true,
}
lib.specialTypes = {
	["aq"] = true,
	["vashj'ir"] = true,
}
--- Retrieves a hash table of all mounts in the db of a certain type
-- @param MountType acceptable types include: ground, air, water, AQ, Vashj'ir
-- @usage local mounts = LibStub("LibMounts-1.0"):GetMountList(type)
-- @return **mountTable** <<color 00f>>hash table<</color>> returns a hash table of mount ID's from the given mount type (mounts with special speeds are not returned)
function lib:GetMountList(MountType)
	local t = {}
	MountType = MountType:lower()
	if lib.normalTypes[MountType] then
		for id in pairs(lib.data[MountType]) do
			if not lib.data.specialSpeed[id] then
				t[id] = true
			end
		end
	elseif lib.specialTypes[MountType] then
		for id, pack in pairs(lib.data.specialLocation) do
			if pack[5]:lower() == MountType then
				t[id] = true
			end
		end
	end
	return t
end